# Community

Welcome to the Dynamiqs community! You can get involved in the project by:

- Opening issues in the GitHub repository, see [GitHub Issues](https://github.com/dynamiqs/dynamiqs/issues).
- Contributing to the codebase, see [Contributing](contributing.md).
- Reaching out to us, see [Let's talk](lets-talk.md).
- Joining the Dynamiqs community on [Slack](https://join.slack.com/t/dynamiqs-org/shared_invite/zt-1z4mw08mo-qDLoNx19JBRtKzXlmlFYLA).
- Citing Dynamiqs in your research, see [Citing Dynamiqs](citing.md).

We always welcome issue raisers, contributors, and quantum physics lovers. Come and help us make Dynamiqs better!
